tsseg.algorithms.icid package
=============================

aNNEspace embedding → dissimilarity score → automatic psi selection → adaptive
threshold.

| **Type:** change point detection
| **Supervision:** fully unsupervised
| **Requires:** sklearn

**Implementation:** Adapted from MATLAB iCID by Yang Cao (Deakin University). GPLv3.

**Reference:** Cao et al. (2024), JAIR.

Submodules
----------

tsseg.algorithms.icid.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.icid.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.icid
   :members:
   :show-inheritance:
   :undoc-members:
